@@ -5,11 +5,13 @@ from kbrainsdk.admin import Admin
 from kbrainsdk.llms import LLMs
 from kbrainsdk.datasets import Datasets
 from kbrainsdk.ingest import Ingest
+from kbrainsdk.ai import AI
 
 VALID_MODEL_NAMES = ["gpt-3.5-turbo", "gpt-4", "gpt-3.5-instruct"]
 
 class KBRaiNAPI:
     def __init__(self, base_url=None, account_id=None, api_key=None):
+        self.KBRAIN_NAME = "KBRaiN ™"
         self.base_url = base_url or os.getenv('KBRAIN_BASE_URL')
         account_id = account_id or os.getenv('KBRAIN_ACCOUNT_ID')
         api_key = api_key or os.getenv('KBRAIN_API_KEY')
@@ -20,6 +22,7 @@ class KBRaiNAPI:
         self.llms = LLMs(self)
         self.datasets = Datasets(self)
         self.ingest = Ingest(self)
+        self.ai = AI(self)
         
     def healthy(self):
         path = f"/health/v1"
